@@ -15,3 +15,5 @@ from ARgorithmToolkit.array import Array
 from ARgorithmToolkit.string import String
 from ARgorithmToolkit.linkedlist import LinkedList,LinkedListNode,ForwardList
 from ARgorithmToolkit.doublylinkedlist import DoublyLinkedList,DoublyLinkedListNode,List
+from ARgorithmToolkit.map import Map
+from ARgorithmToolkit.set import Set
