@@ -1,6 +1,5 @@
-"""Invokes the console scripts for CLI
-"""
+"""Invokes the console scripts for CLI."""
 
 if __name__ == "__main__":
     from ARgorithmToolkit.cli import app
-    app()
\ No newline at end of file
+    app()
